/*     */ package com.flir.flironesdk;
/*     */ 
/*     */ import android.content.BroadcastReceiver;
/*     */ import android.content.Context;
/*     */ import android.content.Intent;
/*     */ import android.content.IntentFilter;
/*     */ import android.hardware.usb.UsbDevice;
/*     */ import android.hardware.usb.UsbDeviceConnection;
/*     */ import android.hardware.usb.UsbManager;
/*     */ import android.util.Log;
/*     */ import android.util.SparseArray;
/*     */ import com.flir.flironesdk.usb.UsbCommunicator;
/*     */ import com.flir.flironesdk.usb.UsbCommunicator.Delegate;
/*     */ import com.flir.flironesdk.usb.UsbCommunicator.ProtocolType;
/*     */ import java.io.ByteArrayInputStream;
/*     */ import java.io.Closeable;
/*     */ import java.io.File;
/*     */ import java.util.EnumSet;
/*     */ import java.util.HashMap;
/*     */ import java.util.Map.Entry;
/*     */ import java.util.zip.ZipInputStream;
/*     */ 
/*     */ public class Device implements Closeable
/*     */ {
/*     */   protected Delegate delegate;
/*     */   protected UsbCommunicator.Delegate usbDelegate;
/*     */   protected UsbDevice usbDevice;
/*     */   protected static Device cachedDevice;
/*     */   private static Delegate cachedDelegate;
/*     */   private static Context cachedContext;
/*     */   
/*     */   static
/*     */   {
/*  34 */     System.loadLibrary("jnidevicewrapper");
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public static enum TuningState
/*     */   {
/*  44 */     TuningRequired, 
/*     */     
/*     */ 
/*     */ 
/*  48 */     InProgress, 
/*     */     
/*     */ 
/*     */ 
/*  52 */     Tuned, 
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*  57 */     TuningSuggested, 
/*     */     
/*     */ 
/*     */ 
/*  61 */     ApproximatelyTuned, 
/*     */     
/*     */ 
/*     */ 
/*  65 */     Unknown;
/*     */     
/*     */ 
/*     */ 
/*     */     private TuningState() {}
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   public static enum BatteryChargingState
/*     */   {
/*  76 */     NO_CHARGING(1), 
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*  81 */     MANAGED_CHARGING(2), 
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*  86 */     FAULT(4), 
/*     */     
/*     */ 
/*     */ 
/*  90 */     FAULT_HEAT(5), 
/*     */     
/*     */ 
/*     */ 
/*  94 */     FAULT_BAD_CHARGER(6), 
/*     */     
/*     */ 
/*     */ 
/*  98 */     CHARGING_SMART_PHONE_FAULT_HEAT(7), 
/*     */     
/*     */ 
/*     */ 
/* 102 */     MANAGED_CHARGING_ONLY(8), 
/*     */     
/*     */ 
/*     */ 
/* 106 */     CHARGING_SMART_PHONE_ONLY(9), 
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/* 112 */     BAD(255);
/* 113 */     static { lookup = new SparseArray(10);
/*     */       
/*     */ 
/*     */ 
/* 117 */       for (BatteryChargingState s : EnumSet.allOf(BatteryChargingState.class)) {
/* 118 */         lookup.put(s.getValue(), s);
/*     */       }
/*     */     }
/*     */     
/*     */     public static BatteryChargingState get(int value) {
/* 123 */       BatteryChargingState got = (BatteryChargingState)lookup.get(value);
/* 124 */       if (got == null) {
/* 125 */         Log.w("FLIROneSDK", "Error: unknown battery charging state reported.");
/* 126 */         got = BAD;
/*     */       }
/* 128 */       return got;
/*     */     }
/*     */     
/*     */     private BatteryChargingState(int value) {
/* 132 */       this.value = value;
/*     */     }
/*     */     
/* 135 */     int getValue() { return this.value; }
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     private static final SparseArray<BatteryChargingState> lookup;
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     private final int value;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/* 222 */   private static boolean unresolvedPermission = false;
/* 223 */   private static boolean registeredReceiver = false;
/*     */   private static final String ACTION_USB_PERMISSION = "com.android.example.USB_PERMISSION";
/*     */   private static final String ACTION_USB_DISCONNECT = "android.hardware.usb.action.USB_DEVICE_DETACHED";
/*     */   private static final String ACTION_USB_CONNECT = "android.hardware.usb.action.USB_DEVICE_ATTACHED";
/*     */   
/*     */   private static String usbDeviceString(UsbDevice usbDevice)
/*     */   {
/* 230 */     if (usbDevice == null) {
/* 231 */       return "(null)";
/*     */     }
/*     */     
/* 234 */     return "(ProductID = 0x" + Integer.toHexString(usbDevice.getProductId()) + ", " + "VendorID = 0x" + Integer.toHexString(usbDevice.getVendorId()) + ")";
/*     */   }
/*     */   
/*     */ 
/* 238 */   private static BroadcastReceiver mUsbReceiver = new BroadcastReceiver()
/*     */   {
/*     */     public void onReceive(Context context, Intent intent) {
/* 241 */       String action = intent.getAction();
/* 242 */       UsbDevice usbDevice = (UsbDevice)intent.getParcelableExtra("device");
/*     */       
/* 244 */       if ("android.hardware.usb.action.USB_DEVICE_ATTACHED".equals(action)) {
/* 245 */         Log.i("Device", "Received USB Device connect event " + Device.usbDeviceString(usbDevice));
/* 246 */         Device.connectToArbitraryDevice(context);
/* 247 */       } else if ("com.android.example.USB_PERMISSION".equals(action)) {
/* 248 */         boolean DEFAULT_EXTRA_VALUE = false;
/*     */         
/* 250 */         boolean PERMISSION_SUCCESSFULLY_GRANTED = intent.getBooleanExtra("permission", false);
/*     */         
/*     */ 
/*     */ 
/* 254 */         if (PERMISSION_SUCCESSFULLY_GRANTED) {
/* 255 */           Log.i("Device", "Permission granted for USB device " + Device.usbDeviceString(usbDevice));
/* 256 */           Device.connectToArbitraryDevice(context);
/*     */         } else {
/* 258 */           Log.w("Device", "Permission denied for USB device " + Device.usbDeviceString(usbDevice));
/*     */         }
/* 260 */       } else if ("android.hardware.usb.action.USB_DEVICE_DETACHED".equals(action)) {
/* 261 */         if ((Device.cachedDevice != null) && (usbDevice.equals(Device.cachedDevice.usbDevice))) {
/* 262 */           Log.i("Device", "Received USB Device disconnect event for currently connected FLIR ONE device, shutting it down");
/* 263 */           Device.cachedDevice.close();
/* 264 */           Device.connectToArbitraryDevice(context);
/*     */         } else {
/* 266 */           Log.i("Device", "Received irrelevant USB device disconnect event. Event device = " + 
/* 267 */             Device.usbDeviceString(usbDevice) + ", " + "Cached device = " + 
/* 268 */             Device.usbDeviceString(Device.cachedDevice == null ? null : Device.cachedDevice.usbDevice));
/*     */         }
/*     */       }
/*     */     }
/*     */   };
/*     */   protected UsbCommunicator usbCommunicator;
/*     */   
/* 275 */   private static void connectToSpecificUSBDevice(Context context, UsbDevice usbDevice) throws Exception { Log.i("Device", "Attempting to connect to USB device " + usbDeviceString(usbDevice));
/*     */     
/*     */ 
/* 278 */     if (cachedDevice != null)
/* 279 */       throw new Exception("Another device is already connected");
/* 280 */     if (usbDevice == null) {
/* 281 */       throw new Exception("Attempted to connect to a null device");
/*     */     }
/*     */     
/* 284 */     UsbManager manager = (UsbManager)context.getSystemService("usb");
/*     */     
/* 286 */     if (manager == null) {
/* 287 */       throw new Exception("Unable to acquire UsbManager instance");
/*     */     }
/*     */     
/* 290 */     UsbDeviceConnection usbConnection = manager.openDevice(usbDevice);
/*     */     
/* 292 */     if (usbConnection == null) {
/* 293 */       throw new Exception("Unable to open a UsbDeviceConnection");
/*     */     }
/*     */     
/* 296 */     cachedDevice = new Device(usbDevice, usbConnection, cachedDelegate);
/*     */     
/*     */ 
/* 299 */     cachedDevice.open();
/*     */   }
/*     */   
/*     */   protected static void connectToArbitraryDevice(Context context) {
/* 303 */     Log.i("Device", "Attemping to connect to any valid USB device");
/*     */     
/*     */ 
/*     */ 
/* 307 */     if (cachedDevice != null) {
/* 308 */       Log.i("Device", "Connection already active, doing nothing!");
/* 309 */       return;
/*     */     }
/* 311 */     if (!registeredReceiver) {
/* 312 */       Log.i("Device", "Discovery not active, doing nothing!");
/* 313 */       return;
/*     */     }
/*     */     
/* 316 */     boolean connectionSucceeded = false;
/* 317 */     UsbDevice validDeviceWithoutPermission = null;
/* 318 */     UsbManager manager = (UsbManager)context.getSystemService("usb");
/*     */     
/* 320 */     for (Map.Entry<String, UsbDevice> usbDeviceEntry : manager.getDeviceList().entrySet()) {
/* 321 */       UsbDevice device = (UsbDevice)usbDeviceEntry.getValue();
/*     */       
/* 323 */       if (UsbCommunicator.deviceIsValid(device)) {
/* 324 */         if (manager.hasPermission(device)) {
/*     */           try {
/* 326 */             connectToSpecificUSBDevice(context, device);
/* 327 */             connectionSucceeded = true;
/*     */           } catch (Exception e) {
/* 329 */             Log.e("Device", "Unable to connect to USB device: " + e.getMessage());
/*     */           }
/* 331 */         } else if (validDeviceWithoutPermission == null) {
/* 332 */           validDeviceWithoutPermission = device;
/*     */         }
/*     */       }
/*     */     }
/*     */     
/* 337 */     if ((!connectionSucceeded) && (validDeviceWithoutPermission != null)) {
/* 338 */       Log.i("Device", "Requesting permission for valid USB device " + usbDeviceString(validDeviceWithoutPermission));
/* 339 */       manager.requestPermission(validDeviceWithoutPermission, 
/*     */       
/* 341 */         android.app.PendingIntent.getBroadcast(context, 0, new Intent("com.android.example.USB_PERMISSION"), 0));
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   private static void updateCameraFiles(byte[] zipFileBytes)
/*     */   {
/* 357 */     ByteArrayInputStream bis = new ByteArrayInputStream(zipFileBytes);
/*     */     
/* 359 */     ZipInputStream zis = new ZipInputStream(bis);
/* 360 */     FrameProcessor.updateCameraFiles(zis, cachedContext.getFilesDir().getAbsolutePath() + File.separator);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public static void startDiscovery(Context context, Delegate delegate)
/*     */     throws IllegalStateException
/*     */   {
/* 375 */     if (registeredReceiver) {
/* 376 */       throw new IllegalStateException("Device discovery already started");
/*     */     }
/*     */     
/* 379 */     Log.i("Device", "Starting USB device discovery");
/*     */     
/* 381 */     cachedContext = context.getApplicationContext();
/* 382 */     cachedDelegate = delegate;
/*     */     
/* 384 */     cachedContext.registerReceiver(mUsbReceiver, new IntentFilter("android.hardware.usb.action.USB_DEVICE_DETACHED"));
/* 385 */     cachedContext.registerReceiver(mUsbReceiver, new IntentFilter("com.android.example.USB_PERMISSION"));
/* 386 */     cachedContext.registerReceiver(mUsbReceiver, new IntentFilter("android.hardware.usb.action.USB_DEVICE_ATTACHED"));
/*     */     
/* 388 */     registeredReceiver = true;
/*     */     
/* 390 */     connectToArbitraryDevice(context);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public static void stopDiscovery()
/*     */   {
/* 401 */     Log.i("Device", "Stopping USB device discovery");
/*     */     
/* 403 */     if (registeredReceiver) {
/* 404 */       cachedContext.unregisterReceiver(mUsbReceiver);
/* 405 */       registeredReceiver = false;
/*     */     }
/* 407 */     if (cachedDevice != null) {
/* 408 */       cachedDevice.close();
/*     */     }
/*     */   }
/*     */   
/*     */   protected Device() throws Exception {
/* 413 */     if (cachedDevice != null) {
/* 414 */       throw new Exception("Attempted to connect a Device when another was already connected!");
/*     */     }
/*     */     
/* 417 */     Log.i("Device", "Creating UsbCommunicator.Delegate");
/* 418 */     cachedDevice = this;
/*     */     
/*     */ 
/* 421 */     this.usbDelegate = new UsbCommunicator.Delegate()
/*     */     {
/*     */       public void onCommunicationAvailabilityChange(boolean transportDidBecomeAvailable)
/*     */       {
/* 425 */         Log.d("Device", "onCommunicationAvailabilityChange!");
/* 426 */         Device.this.deviceConnectionDidChange(transportDidBecomeAvailable);
/*     */       }
/*     */       
/*     */ 
/*     */       public void onDataReceived(byte[] data, UsbCommunicator.ProtocolType protocolType)
/*     */       {
/* 432 */         Device.this.handleDataFromDevice(data, protocolType);
/*     */       }
/*     */     };
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   private Device(UsbDevice usbDevice, UsbDeviceConnection usbConnection, Delegate delegate)
/*     */     throws Exception
/*     */   {
/* 456 */     this();
/*     */     
/* 458 */     Log.i("Device", "Physical device constructor");
/*     */     
/* 460 */     this.usbDevice = usbDevice;
/* 461 */     this.usbCommunicator = new UsbCommunicator(usbDevice, usbConnection, this.usbDelegate);
/* 462 */     this.delegate = delegate;
/* 463 */     initNativeBridge(delegate);
/* 464 */     setUsbCommunicator(this.usbCommunicator);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   void open()
/*     */   {
/* 472 */     Log.i("Device", "Opening device");
/*     */     
/* 474 */     if (this.usbCommunicator != null) {
/* 475 */       Log.i("Device", "Opening USB device");
/* 476 */       this.usbCommunicator.connect();
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void close()
/*     */   {
/* 510 */     Log.i("Device", "Closing device");
/*     */     
/* 512 */     if (this == cachedDevice) {
/* 513 */       stopFrameStream();
/* 514 */       if (this.usbCommunicator != null) {
/* 515 */         this.usbCommunicator.close();
/*     */       }
/* 517 */       cachedDevice = null;
/* 518 */       connectToArbitraryDevice(cachedContext);
/*     */     } else {
/* 520 */       Log.w("Device", "Attempted to close already-closed device instance!");
/*     */     }
/*     */   }
/*     */   
/*     */   public native void startFrameStream(StreamDelegate paramStreamDelegate);
/*     */   
/*     */   public native void stopFrameStream();
/*     */   
/*     */   protected native void initNativeBridge(Delegate paramDelegate);
/*     */   
/*     */   protected native void setUsbCommunicator(UsbCommunicator paramUsbCommunicator);
/*     */   
/*     */   protected native void unregisterDelegate(Delegate paramDelegate);
/*     */   
/*     */   public native void setPowerUpdateDelegate(PowerUpdateDelegate paramPowerUpdateDelegate);
/*     */   
/*     */   public native void performTuning();
/*     */   
/*     */   public native void setAutomaticTuning(boolean paramBoolean);
/*     */   
/*     */   native void handleDataFromDevice(byte[] paramArrayOfByte, UsbCommunicator.ProtocolType paramProtocolType);
/*     */   
/*     */   native void deviceConnectionDidChange(boolean paramBoolean);
/*     */   
/*     */   public static abstract interface StreamDelegate
/*     */   {
/*     */     public abstract void onFrameReceived(Frame paramFrame);
/*     */   }
/*     */   
/*     */   public static abstract interface PowerUpdateDelegate
/*     */   {
/*     */     public abstract void onBatteryChargingStateReceived(Device.BatteryChargingState paramBatteryChargingState);
/*     */     
/*     */     public abstract void onBatteryPercentageReceived(byte paramByte);
/*     */   }
/*     */   
/*     */   public static abstract interface Delegate
/*     */   {
/*     */     public abstract void onTuningStateChanged(Device.TuningState paramTuningState);
/*     */     
/*     */     public abstract void onAutomaticTuningChanged(boolean paramBoolean);
/*     */     
/*     */     public abstract void onDeviceConnected(Device paramDevice);
/*     */     
/*     */     public abstract void onDeviceDisconnected(Device paramDevice);
/*     */   }
/*     */ }


/* Location:              D:\Android\FLIROneSDK-Android-1_0_2\FLIROneSDKBundle\FLIRONEExampleApplication\app\libs\flironesdk\jars\classes.jar!\com\flir\flironesdk\Device.class
 * Java compiler version: 7 (51.0)
 * JD-Core Version:       0.7.1
 */