/*     */ package com.flir.flironesdk;
/*     */ 
/*     */ import android.content.Context;
/*     */ import android.content.res.Resources;
/*     */ import java.io.BufferedOutputStream;
/*     */ import java.io.File;
/*     */ import java.io.FileNotFoundException;
/*     */ import java.io.FileOutputStream;
/*     */ import java.io.IOException;
/*     */ import java.io.InputStream;
/*     */ import java.util.Collections;
/*     */ import java.util.Map;
/*     */ import java.util.Set;
/*     */ import java.util.zip.ZipEntry;
/*     */ import java.util.zip.ZipInputStream;
/*     */ 
/*     */ public final class FrameProcessor
/*     */ {
/*     */   public static final float EMISSIVITY_GLOSSY = 0.3F;
/*     */   public static final float EMISSIVITY_SEMI_GLOSSY = 0.6F;
/*     */   public static final float EMISSIVITY_SEMI_MATTE = 0.8F;
/*     */   public static final float EMISSIVITY_MATTE = 0.95F;
/*     */   static final float EMISSIVITY_DEFAULT = 0.95F;
/*     */   
/*     */   static
/*     */   {
/*  27 */     System.loadLibrary("jnidevicewrapper");
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*  63 */   private float msxDistance = 1.0F;
/*     */   
/*  65 */   private static final byte ILLEGAL_BIT_MASK = (byte)(RenderedImage.ImageType.ThermalRGBA8888Image.getValue() | RenderedImage.ImageType.BlendedMSXRGBA8888Image.getValue());
/*     */   
/*     */   private volatile byte typesBitMask;
/*     */   
/*     */   private float emissivity;
/*     */   
/*     */   private Set<RenderedImage.ImageType> imageTypes;
/*     */   
/*     */   private RenderedImage.Palette framePalette;
/*     */   
/*     */   private Delegate renderDelegate;
/*     */   private static String cameraFilesPath;
/*     */   private Thread renderThread;
/*     */   private volatile Frame currentFrame;
/*     */   
/*     */   private static void deleteDir(File f)
/*     */     throws IOException
/*     */   {
/*  83 */     if (f.isDirectory()) {
/*  84 */       for (File c : f.listFiles())
/*  85 */         deleteDir(c);
/*     */     }
/*  87 */     if (!f.delete()) {
/*  88 */       throw new FileNotFoundException("Failed to delete file: " + f);
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */   static void updateCameraFiles(ZipInputStream zis, String storagePath)
/*     */   {
/*     */     try
/*     */     {
/*     */       ZipEntry ze;
/*     */       
/*  99 */       while ((ze = zis.getNextEntry()) != null) {
/* 100 */         if (ze.isDirectory()) {
/* 101 */           File f = new File(storagePath + ze.getName());
/* 102 */           if (!f.isDirectory()) {
/* 103 */             f.mkdirs();
/*     */           }
/*     */         } else {
/* 106 */           File parentDir = new File(storagePath + ze.getName()).getParentFile();
/* 107 */           if ((null != parentDir) && 
/* 108 */             (!parentDir.isDirectory())) {
/* 109 */             parentDir.mkdirs();
/*     */           }
/*     */           
/* 112 */           BufferedOutputStream bos = new BufferedOutputStream(new FileOutputStream(storagePath + ze.getName()));
/* 113 */           byte[] bytesIn = new byte['က'];
/*     */           int read;
/* 115 */           while ((read = zis.read(bytesIn)) != -1) {
/* 116 */             bos.write(bytesIn, 0, read);
/*     */           }
/* 118 */           zis.closeEntry();
/* 119 */           bos.flush();
/* 120 */           bos.close();
/*     */         }
/*     */       }
/* 123 */       zis.close();
/*     */     } catch (IOException e) {
/* 125 */       e.printStackTrace();
/*     */     }
/*     */   }
/*     */   
/* 129 */   private FrameProcessor(Context context) { this.emissivity = 0.95F;
/*     */     
/*     */ 
/* 132 */     String storagePath = context.getFilesDir().getAbsolutePath() + File.separator;
/* 133 */     cameraFilesPath = storagePath + "CameraFiles";
/* 134 */     Boolean cameraFilesExists = Boolean.valueOf(new File(cameraFilesPath).exists());
/*     */     
/*     */ 
/*     */ 
/*     */ 
/* 139 */     InputStream defaultCameraFilesInput = context.getApplicationContext().getResources().openRawResource(R.raw.default_camera_files);
/* 140 */     ZipInputStream zis = new ZipInputStream(new java.io.BufferedInputStream(defaultCameraFilesInput));
/* 141 */     updateCameraFiles(zis, storagePath);
/*     */     
/* 143 */     setupAppCore(cameraFilesPath);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public FrameProcessor(Context context, Delegate delegate, Set<RenderedImage.ImageType> types)
/*     */     throws IllegalArgumentException
/*     */   {
/* 158 */     this(context);
/* 159 */     setImageTypes(types);
/* 160 */     this.framePalette = RenderedImage.Palette.Iron;
/* 161 */     this.renderDelegate = delegate;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public synchronized void setImageTypes(Set<RenderedImage.ImageType> types)
/*     */   {
/* 176 */     byte bitMask = 0;
/* 177 */     for (RenderedImage.ImageType type : types) {
/* 178 */       bitMask = (byte)(bitMask | type.getValue());
/*     */     }
/*     */     
/* 181 */     if ((bitMask == 0) || (ILLEGAL_BIT_MASK == (ILLEGAL_BIT_MASK & bitMask)))
/*     */     {
/*     */ 
/*     */ 
/*     */ 
/* 186 */       throw new IllegalArgumentException();
/*     */     }
/* 188 */     this.typesBitMask = bitMask;
/* 189 */     this.imageTypes = types;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public synchronized Set<RenderedImage.ImageType> getImageTypes()
/*     */   {
/* 198 */     return Collections.unmodifiableSet(this.imageTypes);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public synchronized void setImagePalette(RenderedImage.Palette palette)
/*     */   {
/* 207 */     this.framePalette = palette;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   public RenderedImage.Palette getImagePalette()
/*     */   {
/* 215 */     return this.framePalette;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   public void setEmissivity(float emissivity)
/*     */   {
/* 223 */     this.emissivity = emissivity;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   public float getEmissivity()
/*     */   {
/* 231 */     return this.emissivity;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void setMSXDistance(float distance)
/*     */   {
/* 240 */     this.msxDistance = distance;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   public double getMSXDistance()
/*     */   {
/* 248 */     return this.msxDistance;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public synchronized void processFrame(Frame frame)
/*     */   {
/* 274 */     final FrameProcessor instance = this;
/* 275 */     if (this.renderThread == null) {
/* 276 */       this.renderThread = new Thread(new Runnable()
/*     */       {
/*     */         public void run()
/*     */         {
/* 280 */           synchronized (instance) {
/* 281 */             instance.notify();
/*     */             try
/*     */             {
/*     */               for (;;) {
/* 285 */                 instance.wait();
/*     */                 
/* 287 */                 synchronized (FrameProcessor.class) {
/* 288 */                   FrameProcessor.this.processFrame(FrameProcessor.this.currentFrame, FrameProcessor.this.typesBitMask, FrameProcessor.this.emissivity, FrameProcessor.this.msxDistance);
/*     */                 }
/*     */               }
/*     */             }
/*     */             catch (InterruptedException ex) {
/* 293 */               ex.printStackTrace();
/*     */             }
/*     */             
/*     */           }
/*     */         }
/* 298 */       });
/* 299 */       this.renderThread.setPriority(10);
/*     */       
/*     */ 
/* 302 */       synchronized (instance) {
/* 303 */         this.renderThread.start();
/*     */         try {
/* 305 */           instance.wait();
/*     */         } catch (InterruptedException e) {
/* 307 */           e.printStackTrace();
/*     */         }
/*     */       }
/*     */     }
/* 311 */     this.currentFrame = frame;
/* 312 */     synchronized (instance) {
/* 313 */       instance.notify();
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public Map<RenderedImage.ImageType, RenderedImage> getProcessedFrames(Frame frame)
/*     */   {
/* 324 */     Map<RenderedImage.ImageType, RenderedImage> map = new java.util.EnumMap(RenderedImage.ImageType.class);
/* 325 */     synchronized (FrameProcessor.class)
/*     */     {
/* 327 */       if ((frame instanceof LoadedFrame)) {
/* 328 */         processFrameFromFileSynchronous(map, ((LoadedFrame)frame).backingFile.getAbsolutePath(), frame, this.typesBitMask, this.emissivity, this.msxDistance);
/*     */       } else {
/* 330 */         processFrameSynchronous(map, frame, this.typesBitMask, this.emissivity, this.msxDistance);
/*     */       }
/*     */     }
/* 333 */     return map;
/*     */   }
/*     */   
/*     */   private static native void setupAppCore(String paramString);
/*     */   
/*     */   public static native void lockPalettes();
/*     */   
/*     */   public static native void unlockPalettes();
/*     */   
/*     */   public static native boolean palettesLocked();
/*     */   
/*     */   private native void processFrame(Frame paramFrame, byte paramByte, float paramFloat1, float paramFloat2);
/*     */   
/*     */   private native void processFrameSynchronous(Map<RenderedImage.ImageType, RenderedImage> paramMap, Frame paramFrame, byte paramByte, float paramFloat1, float paramFloat2);
/*     */   
/*     */   private native void processFrameFromFileSynchronous(Map<RenderedImage.ImageType, RenderedImage> paramMap, String paramString, Frame paramFrame, byte paramByte, float paramFloat1, float paramFloat2);
/*     */   
/*     */   public static abstract interface Delegate
/*     */   {
/*     */     public abstract void onFrameProcessed(RenderedImage paramRenderedImage);
/*     */   }
/*     */ }


/* Location:              D:\Android\FLIROneSDK-Android-1_0_2\FLIROneSDKBundle\FLIRONEExampleApplication\app\libs\flironesdk\jars\classes.jar!\com\flir\flironesdk\FrameProcessor.class
 * Java compiler version: 7 (51.0)
 * JD-Core Version:       0.7.1
 */