/*     */ package com.flir.flironesdk;
/*     */ 
/*     */ import android.graphics.Bitmap;
/*     */ import android.graphics.Bitmap.Config;
/*     */ import android.graphics.BitmapFactory;
/*     */ import android.graphics.Matrix;
/*     */ import android.util.SparseArray;
/*     */ import java.nio.ByteBuffer;
/*     */ import java.nio.ByteOrder;
/*     */ import java.nio.ShortBuffer;
/*     */ import java.util.EnumSet;
/*     */ 
/*     */ public class RenderedImage
/*     */ {
/*     */   private Frame rawFrame;
/*     */   private ImageType imageType;
/*     */   private final Palette palette;
/*     */   
/*     */   public Frame getFrame()
/*     */   {
/*  21 */     return this.rawFrame;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   public static enum Palette
/*     */   {
/*  28 */     Iron, 
/*  29 */     Gray, 
/*  30 */     Rainbow, 
/*  31 */     Contrast, 
/*  32 */     Arctic, 
/*  33 */     Lava, 
/*  34 */     Wheel, 
/*  35 */     Coldest, 
/*  36 */     Hottest;
/*     */     
/*     */ 
/*     */ 
/*     */     private Palette() {}
/*     */   }
/*     */   
/*     */ 
/*     */   public static enum ImageType
/*     */   {
/*  46 */     ThermalLinearFlux14BitImage((byte)1), 
/*     */     
/*     */ 
/*     */ 
/*  50 */     ThermalRGBA8888Image((byte)2), 
/*     */     
/*     */ 
/*     */ 
/*  54 */     BlendedMSXRGBA8888Image((byte)4), 
/*     */     
/*     */ 
/*     */ 
/*  58 */     VisualJPEGImage((byte)8), 
/*     */     
/*     */ 
/*     */ 
/*  62 */     VisualYCbCr888Image((byte)16), 
/*     */     
/*     */ 
/*     */ 
/*  66 */     ThermalRadiometricKelvinImage((byte)32);
/*     */     
/*  68 */     static { lookup = new SparseArray(6);
/*     */       
/*     */ 
/*     */ 
/*  72 */       for (ImageType s : EnumSet.allOf(ImageType.class))
/*  73 */         lookup.put(s.getValue(), s);
/*     */     }
/*     */     
/*     */     static ImageType get(byte value) {
/*  77 */       return (ImageType)lookup.get(value);
/*     */     }
/*     */     
/*     */     private ImageType(byte value) {
/*  81 */       this.value = value;
/*     */     }
/*     */     
/*  84 */     byte getValue() { return this.value; }
/*     */     
/*     */ 
/*     */ 
/*     */     private static final SparseArray<ImageType> lookup;
/*     */     
/*     */     public boolean isColorized()
/*     */     {
/*  92 */       EnumSet colorizedTypes = EnumSet.of(ThermalRGBA8888Image, ThermalRGBA8888Image, BlendedMSXRGBA8888Image);
/*  93 */       return colorizedTypes.contains(this);
/*     */     }
/*     */     
/*     */ 
/*     */ 
/*     */     private final byte value;
/*     */   }
/*     */   
/*     */ 
/*     */   public ImageType imageType()
/*     */   {
/* 104 */     return this.imageType;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public Palette palette()
/*     */   {
/* 113 */     return this.palette;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/* 120 */   public float emissivity() { return this.emissivity; }
/* 121 */   private float emissivity = 0.0F;
/*     */   private final int width;
/*     */   private final int height;
/*     */   private byte[] pixelData;
/*     */   
/* 126 */   public int width() { return this.width; }
/*     */   
/*     */   public int height() {
/* 129 */     return this.height;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public byte[] pixelData()
/*     */   {
/* 139 */     return this.pixelData;
/*     */   }
/*     */   
/*     */ 
/*     */   public Bitmap getBitmap()
/*     */   {
/*     */     Bitmap outputBitmap;
/*     */     
/*     */     Bitmap outputBitmap;
/*     */     
/* 149 */     if (this.imageType == ImageType.VisualJPEGImage) {
/* 150 */       Bitmap visBitmap = BitmapFactory.decodeByteArray(this.pixelData, 0, this.pixelData.length);
/*     */       
/*     */ 
/* 153 */       Matrix mtx = new Matrix();
/* 154 */       mtx.postRotate(90.0F);
/* 155 */       outputBitmap = Bitmap.createBitmap(visBitmap, 0, 0, visBitmap.getWidth(), visBitmap.getHeight(), mtx, true);
/* 156 */     } else if ((this.imageType == ImageType.VisualYCbCr888Image) || (this.imageType.isColorized())) {
/* 157 */       Bitmap outputBitmap = Bitmap.createBitmap(this.width, this.height, Bitmap.Config.ARGB_8888);
/*     */       
/* 159 */       outputBitmap.copyPixelsFromBuffer(ByteBuffer.wrap(this.pixelData));
/*     */     }
/*     */     else
/*     */     {
/* 163 */       outputBitmap = Bitmap.createBitmap(this.width, this.height, Bitmap.Config.ARGB_8888);
/*     */       
/*     */ 
/*     */ 
/* 167 */       short[] shortPixels = new short[pixelData().length / 2];
/* 168 */       byte[] argbPixels = new byte[this.width * this.height * 4];
/*     */       
/* 170 */       ByteBuffer.wrap(pixelData()).order(ByteOrder.LITTLE_ENDIAN).asShortBuffer().get(shortPixels);
/* 171 */       byte aPixValue = -1;
/*     */       
/* 173 */       if (imageType() == ImageType.ThermalLinearFlux14BitImage) {
/* 174 */         int minValue = 65535;
/* 175 */         int maxValue = 0;
/* 176 */         for (int p = 0; p < shortPixels.length; p++) {
/* 177 */           minValue = Math.min(minValue, shortPixels[p]);
/* 178 */           maxValue = Math.max(maxValue, shortPixels[p]);
/*     */         }
/*     */         
/* 181 */         int range = maxValue - minValue;
/* 182 */         float scale = 255.0F / range;
/* 183 */         for (int p = 0; p < shortPixels.length; p++) {
/* 184 */           int destP = p * 4;
/*     */           
/* 186 */           short pixelValue = (short)(int)((shortPixels[p] - minValue) * scale);
/*     */           
/* 188 */           argbPixels[(destP + 3)] = -1;
/* 189 */           argbPixels[destP] = (argbPixels[(destP + 1)] = argbPixels[(destP + 2)] = (byte)pixelValue);
/*     */         }
/*     */       } else {
/* 192 */         float scale = 0.0038909912F;
/* 193 */         for (int p = 0; p < shortPixels.length; p++) {
/* 194 */           int destP = p * 4;
/* 195 */           byte pixValue = (byte)Math.round(shortPixels[p] * 0.0038909912F);
/*     */           
/* 197 */           argbPixels[(destP + 3)] = -1;
/*     */           
/* 199 */           argbPixels[destP] = (argbPixels[(destP + 1)] = argbPixels[(destP + 2)] = pixValue);
/*     */         }
/*     */       }
/*     */       
/* 203 */       outputBitmap.copyPixelsFromBuffer(ByteBuffer.wrap(argbPixels));
/*     */     }
/*     */     
/* 206 */     return outputBitmap;
/*     */   }
/*     */   
/*     */   private RenderedImage()
/*     */   {
/* 211 */     this.width = 0;
/* 212 */     this.height = 0;
/* 213 */     this.palette = null;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   private RenderedImage(int width, int height, byte[] pixelData, byte frameTypeValue, float emissivity, int paletteOrdinal, Frame originalFrame)
/*     */   {
/* 228 */     this.width = width;
/* 229 */     this.height = height;
/* 230 */     this.pixelData = pixelData;
/* 231 */     this.imageType = ImageType.get(frameTypeValue);
/* 232 */     this.emissivity = emissivity;
/* 233 */     if ((paletteOrdinal >= 0) && (paletteOrdinal < Palette.values().length)) {
/* 234 */       this.palette = Palette.values()[paletteOrdinal];
/*     */     } else {
/* 236 */       this.palette = null;
/*     */     }
/* 238 */     this.rawFrame = originalFrame;
/*     */   }
/*     */ }


/* Location:              D:\Android\FLIROneSDK-Android-1_0_2\FLIROneSDKBundle\FLIRONEExampleApplication\app\libs\flironesdk\jars\classes.jar!\com\flir\flironesdk\RenderedImage.class
 * Java compiler version: 7 (51.0)
 * JD-Core Version:       0.7.1
 */