/*     */ package com.flir.flironesdk;
/*     */ 
/*     */ import android.util.Log;
/*     */ import com.flir.flironesdk.usb.UsbCommunicator;
/*     */ import java.io.BufferedInputStream;
/*     */ import java.io.ByteArrayOutputStream;
/*     */ import java.io.InputStream;
/*     */ import java.util.concurrent.ScheduledThreadPoolExecutor;
/*     */ import java.util.concurrent.TimeUnit;
/*     */ import java.util.zip.ZipEntry;
/*     */ import java.util.zip.ZipInputStream;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SimulatedDevice
/*     */   extends Device
/*     */ {
/*     */   private native void startSimulator();
/*     */   
/*     */   private native void stopSimulator();
/*     */   
/*     */   private native void addSimulatedFrame(byte[] paramArrayOfByte1, byte[] paramArrayOfByte2);
/*     */   
/*  29 */   private static long BATTERY_TIMER_UPDATE_INTERVAL_IN_MILLISECONDS = 1000L;
/*  30 */   private static long FULL_BATTERY_DISCHARGE_TIME_IN_MILLISECONDS = 10000L;
/*  31 */   private static long FULL_BATTERY_CHARGE_TIME_IN_MILLISECONDS = 5000L;
/*     */   private ScheduledThreadPoolExecutor periodicEventExecutor;
/*     */   private float storedBatteryChargePercentage;
/*     */   
/*  35 */   private boolean chargeCableIsConnected = true;
/*     */   
/*     */ 
/*     */   private native void clearSimulatedFrames();
/*     */   
/*     */ 
/*     */   private native void setBatteryChargePercentage(float paramFloat);
/*     */   
/*     */   private native void setNativeChargeCableState(boolean paramBoolean);
/*     */   
/*     */   private synchronized void batteryChargeTimerFired()
/*     */   {
/*  47 */     float OLD_BATTERY_CHARGE_PERCENTAGE = this.storedBatteryChargePercentage;
/*  48 */     float newBatteryChargePercentage = OLD_BATTERY_CHARGE_PERCENTAGE;
/*     */     
/*  50 */     if (this.chargeCableIsConnected) {
/*  51 */       newBatteryChargePercentage += 100.0F * (float)BATTERY_TIMER_UPDATE_INTERVAL_IN_MILLISECONDS / (float)FULL_BATTERY_CHARGE_TIME_IN_MILLISECONDS;
/*     */     } else {
/*  53 */       newBatteryChargePercentage -= 100.0F * (float)BATTERY_TIMER_UPDATE_INTERVAL_IN_MILLISECONDS / (float)FULL_BATTERY_DISCHARGE_TIME_IN_MILLISECONDS;
/*     */     }
/*     */     
/*  56 */     if (newBatteryChargePercentage > 100.0F) {
/*  57 */       newBatteryChargePercentage = 100.0F;
/*  58 */     } else if (newBatteryChargePercentage < 0.0F) {
/*  59 */       newBatteryChargePercentage = 0.0F;
/*     */     }
/*     */     
/*  62 */     this.storedBatteryChargePercentage = newBatteryChargePercentage;
/*     */     
/*  64 */     if (newBatteryChargePercentage < 1.0F) {
/*  65 */       close();
/*  66 */     } else if ((int)newBatteryChargePercentage != (int)OLD_BATTERY_CHARGE_PERCENTAGE) {
/*  67 */       setBatteryChargePercentage(newBatteryChargePercentage);
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public SimulatedDevice(Device.Delegate delegate, InputStream sampleFramesZipData, float initialBatteryPercentage)
/*     */     throws Exception
/*     */   {
/*  84 */     Log.i("Device", "Simulated device constructor");
/*  85 */     this.delegate = delegate;
/*  86 */     this.usbCommunicator = new UsbCommunicator(this.usbDelegate);
/*  87 */     initNativeBridge(delegate);
/*  88 */     setUsbCommunicator(this.usbCommunicator);
/*     */     
/*  90 */     ZipInputStream zis = new ZipInputStream(new BufferedInputStream(sampleFramesZipData));
/*     */     try {
/*  92 */       clearSimulatedFrames();
/*     */       
/*     */ 
/*  95 */       byte[] visBytes = null;
/*  96 */       byte[] thermalBytes = null;
/*  97 */       boolean visFrameRead = false;
/*  98 */       boolean thermalFrameRead = false;
/*  99 */       ZipEntry ze; while ((ze = zis.getNextEntry()) != null) {
/* 100 */         ByteArrayOutputStream baos = new ByteArrayOutputStream();
/* 101 */         byte[] buffer = new byte['Ѐ'];
/*     */         int count;
/* 103 */         while ((count = zis.read(buffer)) != -1) {
/* 104 */           baos.write(buffer, 0, count);
/*     */         }
/* 106 */         String filename = ze.getName();
/* 107 */         if (filename.contains("vis")) {
/* 108 */           visBytes = baos.toByteArray();
/* 109 */           visFrameRead = true;
/*     */         } else {
/* 111 */           thermalBytes = baos.toByteArray();
/* 112 */           thermalFrameRead = true;
/*     */         }
/* 114 */         if ((thermalFrameRead) && (visFrameRead)) {
/* 115 */           addSimulatedFrame(thermalBytes, visBytes);
/*     */         }
/*     */       }
/*     */     } finally {
/* 119 */       zis.close();
/*     */     }
/*     */     
/* 122 */     this.storedBatteryChargePercentage = initialBatteryPercentage;
/*     */     
/* 124 */     setChargeCableState(this.chargeCableIsConnected);
/* 125 */     setBatteryChargePercentage(this.storedBatteryChargePercentage);
/* 126 */     startSimulator();
/* 127 */     this.periodicEventExecutor = new ScheduledThreadPoolExecutor(1);
/*     */     
/* 129 */     final SimulatedDevice capturedThis = this;
/* 130 */     this.periodicEventExecutor.scheduleAtFixedRate(new Runnable()
/*     */     {
/*     */ 
/* 133 */       public void run() { capturedThis.batteryChargeTimerFired(); } }, BATTERY_TIMER_UPDATE_INTERVAL_IN_MILLISECONDS, BATTERY_TIMER_UPDATE_INTERVAL_IN_MILLISECONDS, TimeUnit.MILLISECONDS);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public synchronized void close()
/*     */   {
/* 147 */     if (cachedDevice == this) {
/* 148 */       this.periodicEventExecutor.shutdownNow();
/* 149 */       stopSimulator();
/* 150 */       super.close();
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public synchronized void setChargeCableState(boolean connected)
/*     */   {
/* 160 */     this.chargeCableIsConnected = connected;
/* 161 */     setNativeChargeCableState(connected);
/*     */   }
/*     */ }


/* Location:              D:\Android\FLIROneSDK-Android-1_0_2\FLIROneSDKBundle\FLIRONEExampleApplication\app\libs\flironesdk\jars\classes.jar!\com\flir\flironesdk\SimulatedDevice.class
 * Java compiler version: 7 (51.0)
 * JD-Core Version:       0.7.1
 */