/*     */ package com.flir.flironesdk.usb;
/*     */ 
/*     */ import android.hardware.usb.UsbEndpoint;
/*     */ import android.hardware.usb.UsbRequest;
/*     */ import java.nio.ByteBuffer;
/*     */ 
/*     */ public class UsbCommunicator implements java.io.Closeable
/*     */ {
/*     */   private boolean IS_SIMULATED;
/*     */   private Delegate mDelegate;
/*     */   private volatile android.hardware.usb.UsbDeviceConnection connection;
/*     */   private static final String LOG_TAG = "UsbCommunicator";
/*     */   private static final int SET_INTERFACE = 11;
/*     */   private static final int CTRL_TRANSFER_TIMEOUT = 200;
/*     */   static final int FRAME_READ_ENDPOINT_ID = 5;
/*     */   static final int CONFIG_READ_ENDPOINT_ID = 1;
/*     */   static final int CONFIG_WRITE_ENDPOINT_ID = 2;
/*     */   static final int FILEIO_READ_ENDPOINT_ID = 3;
/*     */   static final int FILEIO_WRITE_ENDPOINT_ID = 4;
/*     */   static final int SUPPORTED_VENDOR_ID = 2507;
/*     */   static final int SUPPORTED_PRODUCT_ID = 6550;
/*     */   private UsbEndpoint configWriteEndpoint;
/*     */   
/*     */   public static abstract interface Delegate
/*     */   {
/*     */     public abstract void onDataReceived(byte[] paramArrayOfByte, UsbCommunicator.ProtocolType paramProtocolType);
/*     */     
/*     */     public abstract void onCommunicationAvailabilityChange(boolean paramBoolean);
/*     */   }
/*     */   
/*     */   public static enum ProtocolType
/*     */   {
/*  33 */     CONFIGURATION((byte)1), 
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*  39 */     FILEIO((byte)2), 
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*  45 */     FRAME((byte)4);
/*     */     
/*     */     private ProtocolType(byte value) {
/*  48 */       this.value = value;
/*     */     }
/*     */     
/*  51 */     byte getValue() { return this.value; }
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     private final byte value;
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*  93 */   private UsbEndpoint fileioWriteEndpoint = null;
/*  94 */   final UsbRequest frameReadRequest = new UsbRequest();
/*  95 */   final UsbRequest fileioReadRequest = new UsbRequest();
/*  96 */   final UsbRequest configReadRequest = new UsbRequest();
/*     */   
/*     */   private android.hardware.usb.UsbDevice mDevice;
/*     */   
/* 100 */   volatile boolean connected = false;
/* 101 */   volatile boolean expectFrameData = false;
/* 102 */   volatile boolean expectFileData = false;
/*     */   
/*     */   public static boolean deviceIsValid(android.hardware.usb.UsbDevice device) {
/*     */     try {
/* 106 */       validateDevice(device);
/* 107 */       return true;
/*     */     } catch (Exception e) {
/* 109 */       android.util.Log.e("UsbCommunicator", "Invalid device: " + e.getMessage()); }
/* 110 */     return false;
/*     */   }
/*     */   
/*     */   public static void validateDevice(android.hardware.usb.UsbDevice device) throws Exception
/*     */   {
/* 115 */     if (device.getVendorId() != 2507) {
/* 116 */       throw new Exception("Unsupported USB Vendor ID of " + Integer.toHexString(device.getVendorId()));
/*     */     }
/* 118 */     if (device.getProductId() != 6550) {
/* 119 */       throw new Exception("Unsupported USB Product ID of " + Integer.toHexString(device.getProductId()));
/*     */     }
/*     */     
/* 122 */     int ifaceCount = device.getInterfaceCount();
/* 123 */     java.util.HashMap<Integer, Boolean> inEndpointsFound = new java.util.HashMap();
/* 124 */     java.util.HashMap<Integer, Boolean> outEndpointsFound = new java.util.HashMap();
/* 125 */     inEndpointsFound.put(Integer.valueOf(3), Boolean.valueOf(false));
/* 126 */     inEndpointsFound.put(Integer.valueOf(1), Boolean.valueOf(false));
/* 127 */     inEndpointsFound.put(Integer.valueOf(5), Boolean.valueOf(false));
/* 128 */     outEndpointsFound.put(Integer.valueOf(2), Boolean.valueOf(false));
/* 129 */     outEndpointsFound.put(Integer.valueOf(4), Boolean.valueOf(false));
/*     */     android.hardware.usb.UsbInterface iface;
/* 131 */     for (int i = 0; i < ifaceCount; i++) {
/* 132 */       iface = device.getInterface(i);
/*     */       
/* 134 */       int endpointCount = iface.getEndpointCount();
/* 135 */       for (int e = 0; e < endpointCount; e++) {
/* 136 */         UsbEndpoint ep = iface.getEndpoint(e);
/* 137 */         if (ep.getDirection() == 128) {
/* 138 */           inEndpointsFound.put(Integer.valueOf(ep.getEndpointNumber()), Boolean.valueOf(true));
/*     */         } else {
/* 140 */           outEndpointsFound.put(Integer.valueOf(ep.getEndpointNumber()), Boolean.valueOf(true));
/*     */         }
/*     */       }
/*     */     }
/*     */     
/*     */ 
/* 146 */     java.util.HashSet<java.util.Map.Entry<Integer, Boolean>> allEndpointsFound = new java.util.HashSet();
/* 147 */     allEndpointsFound.addAll(inEndpointsFound.entrySet());
/* 148 */     allEndpointsFound.addAll(outEndpointsFound.entrySet());
/* 149 */     for (java.util.Map.Entry<Integer, Boolean> endpoint : allEndpointsFound) {
/* 150 */       if (!((Boolean)endpoint.getValue()).booleanValue())
/*     */       {
/* 152 */         throw new Exception("Unable to communicate with USB device, endpoint " + ((Integer)endpoint.getKey()).toString() + " not found");
/*     */       }
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public UsbCommunicator(android.hardware.usb.UsbDevice device, android.hardware.usb.UsbDeviceConnection usbConnection, Delegate delegate)
/*     */     throws Exception
/*     */   {
/* 165 */     validateDevice(device);
/*     */     
/* 167 */     this.mDelegate = delegate;
/* 168 */     this.connection = usbConnection;
/* 169 */     this.mDevice = device;
/*     */     
/* 171 */     int ifaceCount = device.getInterfaceCount();
/*     */     
/* 173 */     for (int i = 0; i < ifaceCount; i++) {
/* 174 */       android.hardware.usb.UsbInterface iface = device.getInterface(i);
/* 175 */       if (false == this.connection.claimInterface(iface, false)) {
/* 176 */         android.util.Log.e("UsbCommunicator", "Unable to claim interface " + iface.getId() + ", close connection and try again.");
/* 177 */         delegate.onCommunicationAvailabilityChange(false);
/* 178 */         throw new Exception("Unable to claim USB interface");
/*     */       }
/*     */       
/* 181 */       int endpointCount = iface.getEndpointCount();
/* 182 */       for (int e = 0; e < endpointCount; e++) {
/* 183 */         UsbEndpoint ep = iface.getEndpoint(e);
/* 184 */         if (ep.getDirection() == 128) {
/* 185 */           switch (ep.getEndpointNumber()) {
/*     */           case 5: 
/* 187 */             this.frameReadRequest.initialize(this.connection, ep);
/* 188 */             break;
/*     */           case 1: 
/* 190 */             this.configReadRequest.initialize(this.connection, ep);
/* 191 */             break;
/*     */           case 3: 
/* 193 */             this.fileioReadRequest.initialize(this.connection, ep);
/* 194 */             break;
/*     */           case 2: case 4: default: 
/* 196 */             android.util.Log.w("UsbCommunicator", "Unknown USB_DIR_IN Endpoint on device!");break;
/*     */           }
/*     */         } else {
/* 199 */           switch (ep.getEndpointNumber()) {
/*     */           case 2: 
/* 201 */             this.configWriteEndpoint = ep;
/* 202 */             break;
/*     */           case 4: 
/* 204 */             this.fileioWriteEndpoint = ep;
/* 205 */             break;
/*     */           default: 
/* 207 */             android.util.Log.w("UsbCommunicator", "Unknown USB_DIR_OUT Endpoint on device!");
/*     */           }
/*     */           
/*     */         }
/*     */       }
/*     */     }
/* 213 */     if (this.fileioWriteEndpoint != null) {
/* 214 */       stopCommunication(ProtocolType.FRAME);
/* 215 */       stopCommunication(ProtocolType.FILEIO);
/*     */     } else {
/* 217 */       delegate.onCommunicationAvailabilityChange(false);
/*     */     }
/*     */   }
/*     */   
/* 221 */   final int CONFIG_BUFFER_SIZE = 4096;
/* 222 */   final int FRAME_BUFFER_SIZE = 131072;
/* 223 */   final int FILE_BUFFER_SIZE = 1048576;
/* 224 */   final ByteBuffer configBuffer = ByteBuffer.allocate(4096);
/* 225 */   final ByteBuffer frameBuffer = ByteBuffer.allocate(131072);
/* 226 */   final ByteBuffer fileBuffer = ByteBuffer.allocate(1048576);
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   private void pollEndpoints()
/*     */   {
/* 279 */     new Thread(new Runnable()
/*     */     {
/*     */       public void run()
/*     */       {
/* 233 */         android.util.Log.d("configReadRequest", "Starting configReadRequest poll loop...");
/* 234 */         UsbCommunicator.this.configReadRequest.queue(UsbCommunicator.this.configBuffer, 4096);
/*     */         
/* 236 */         while (UsbCommunicator.this.connected) {
/* 237 */           UsbRequest requestResult = UsbCommunicator.this.connection.requestWait();
/* 238 */           synchronized (UsbCommunicator.this.configReadRequest) {
/* 239 */             if (!UsbCommunicator.this.connected) {
/*     */               break;
/*     */             }
/* 242 */             if (requestResult == UsbCommunicator.this.configReadRequest) {
/* 243 */               byte[] data = new byte[UsbCommunicator.this.configBuffer.position()];
/* 244 */               UsbCommunicator.this.configBuffer.flip();
/* 245 */               UsbCommunicator.this.configBuffer.get(data);
/* 246 */               if (data.length > 0) {
/* 247 */                 UsbCommunicator.this.mDelegate.onDataReceived(data, UsbCommunicator.ProtocolType.CONFIGURATION);
/*     */               }
/* 249 */               UsbCommunicator.this.configBuffer.clear();
/* 250 */               UsbCommunicator.this.configReadRequest.queue(UsbCommunicator.this.configBuffer, 4096);
/* 251 */             } else if (requestResult == UsbCommunicator.this.frameReadRequest) {
/* 252 */               byte[] data = new byte[UsbCommunicator.this.frameBuffer.position()];
/* 253 */               UsbCommunicator.this.frameBuffer.flip();
/* 254 */               UsbCommunicator.this.frameBuffer.get(data);
/* 255 */               if (data.length > 0) {
/* 256 */                 UsbCommunicator.this.mDelegate.onDataReceived(data, UsbCommunicator.ProtocolType.FRAME);
/*     */               }
/* 258 */               if (UsbCommunicator.this.expectFrameData) {
/* 259 */                 UsbCommunicator.this.frameReadRequest.queue(UsbCommunicator.this.frameBuffer, 131072);
/*     */               }
/* 261 */               UsbCommunicator.this.frameBuffer.clear();
/* 262 */             } else if (requestResult == UsbCommunicator.this.fileioReadRequest) {
/* 263 */               byte[] data = new byte[UsbCommunicator.this.fileBuffer.position()];
/* 264 */               UsbCommunicator.this.fileBuffer.flip();
/* 265 */               UsbCommunicator.this.fileBuffer.get(data);
/* 266 */               UsbCommunicator.this.mDelegate.onDataReceived(data, UsbCommunicator.ProtocolType.FILEIO);
/* 267 */               UsbCommunicator.this.fileBuffer.clear();
/* 268 */               if (UsbCommunicator.this.expectFileData) {
/* 269 */                 UsbCommunicator.this.fileioReadRequest.queue(UsbCommunicator.this.fileBuffer, 1048576);
/*     */               }
/*     */             }
/*     */           }
/*     */         }
/*     */       }
/*     */     })
/*     */     
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/* 279 */       .start();
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */   public UsbCommunicator(Delegate usbDelegate)
/*     */   {
/* 283 */     android.util.Log.i("UsbCommunicator", "Simulated device constructor");
/* 284 */     this.mDelegate = usbDelegate;
/* 285 */     this.IS_SIMULATED = true;
/*     */   }
/*     */   
/*     */   private void sendData(UsbEndpoint ep, byte[] data, int length)
/*     */   {
/* 290 */     android.util.Log.d("UsbCommunicator", "Sending " + length + " bytes on EP" + ep.getEndpointNumber());
/* 291 */     synchronized (this.connection) {
/* 292 */       int offset = 0;
/* 293 */       while (offset < length) {
/* 294 */         int result = this.connection.bulkTransfer(ep, data, offset, length - offset, 500);
/* 295 */         if (result > 0) {
/* 296 */           android.util.Log.d("UsbCommunicator", "Bulk transfer sent " + result + " bytes on Endpoint " + ep.getEndpointNumber());
/* 297 */           offset += result;
/*     */         } else {
/* 299 */           android.util.Log.w("UsbCommunicator", "Bulk Transfer Failed on Endpoint " + ep.getEndpointNumber());
/*     */         }
/*     */       }
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */   native void sendConfigDataToSimulatedDevice(byte[] paramArrayOfByte);
/*     */   
/*     */ 
/*     */ 
/*     */   public void sendDataToDevice(byte[] data, ProtocolType protocolType)
/*     */   {
/* 313 */     if (this.IS_SIMULATED) {
/* 314 */       switch (protocolType) {
/*     */       case CONFIGURATION: 
/* 316 */         sendConfigDataToSimulatedDevice(data);
/* 317 */         break;
/*     */       }
/*     */     }
/*     */     else {
/*     */       UsbEndpoint destinationEndpoint;
/*     */       UsbEndpoint destinationEndpoint;
/* 323 */       switch (protocolType) {
/*     */       case CONFIGURATION: 
/* 325 */         destinationEndpoint = this.configWriteEndpoint;
/* 326 */         break;
/*     */       case FILEIO: 
/* 328 */         destinationEndpoint = this.fileioWriteEndpoint;
/* 329 */         break;
/*     */       default: 
/* 331 */         android.util.Log.w("UsbCommunicator", "Attempted to send data on knosupported protocol!"); return;
/*     */       }
/*     */       UsbEndpoint destinationEndpoint;
/* 334 */       sendData(destinationEndpoint, data, data.length);
/*     */     }
/*     */   }
/*     */   
/* 338 */   public void sendConfigData(byte[] data) { sendDataToDevice(data, ProtocolType.CONFIGURATION); }
/*     */   
/*     */   public void sendFileioData(byte[] data) {
/* 341 */     sendDataToDevice(data, ProtocolType.FILEIO);
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void close()
/*     */   {
/* 351 */     if (this.connected) {
/* 352 */       pause();
/*     */       
/* 354 */       this.connection.close();
/* 355 */       this.mDelegate.onCommunicationAvailabilityChange(false);
/* 356 */       android.util.Log.d("UsbCommunicator", "Connection closed.");
/*     */     }
/*     */   }
/*     */   
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   public void pause()
/*     */   {
/* 368 */     if (this.connected) {
/* 369 */       synchronized (this.configReadRequest) {
/* 370 */         stopFrames();
/* 371 */         stopCommunication(ProtocolType.FILEIO);
/* 372 */         this.connected = false;
/* 373 */         this.configReadRequest.cancel();
/* 374 */         this.configBuffer.clear();
/*     */         
/* 376 */         this.fileioReadRequest.cancel();
/*     */         
/* 378 */         this.frameReadRequest.cancel();
/*     */       }
/*     */       
/* 381 */       this.mDelegate.onCommunicationAvailabilityChange(false);
/*     */     }
/*     */   }
/*     */   
/*     */   private void startFrames()
/*     */   {
/* 387 */     startCommunication(ProtocolType.FRAME);
/*     */   }
/*     */   
/* 390 */   private void stopFrames() { stopCommunication(ProtocolType.FRAME); }
/*     */   
/*     */   private void startCommunication(ProtocolType protocolType) {
/* 393 */     toggleCommunication(protocolType, true);
/*     */   }
/*     */   
/* 396 */   private void stopCommunication(ProtocolType protocolType) { toggleCommunication(protocolType, false); }
/*     */   
/*     */   private void toggleCommunication(ProtocolType protocolType, boolean startCommunication) {
/* 399 */     if (this.IS_SIMULATED == true) {
/* 400 */       return;
/*     */     }
/*     */     
/* 403 */     switch (protocolType)
/*     */     {
/*     */     case FRAME: 
/* 406 */       int interfaceNumber = 2;
/* 407 */       this.expectFrameData = startCommunication;
/* 408 */       this.frameBuffer.clear();
/* 409 */       if (this.expectFrameData) {
/* 410 */         this.frameReadRequest.queue(this.frameBuffer, 131072);
/*     */       }
/*     */       break;
/*     */     case FILEIO: 
/* 414 */       int interfaceNumber = 1;
/* 415 */       this.expectFileData = startCommunication;
/* 416 */       this.fileBuffer.clear();
/* 417 */       if (this.expectFileData) {
/* 418 */         this.fileioReadRequest.queue(this.fileBuffer, 1048576);
/*     */       }
/*     */       break;
/*     */     case CONFIGURATION: 
/* 422 */       android.util.Log.w("UsbCommunicator", "Configuration Protocol cannot be started or stopped.");
/*     */     default: 
/*     */       return;
/*     */     }
/*     */     int interfaceNumber;
/* 427 */     int altSetting = startCommunication ? 1 : 0;
/* 428 */     synchronized (this.connection) {
/* 429 */       int result = this.connection.controlTransfer(1, 11, altSetting, interfaceNumber, null, 0, 200);
/* 430 */       android.util.Log.d("UsbCommunicator", "Result from control transfer: " + result);
/*     */     }
/*     */   }
/*     */   
/*     */   public void connect()
/*     */   {
/* 436 */     if (!this.connected) {
/* 437 */       this.connected = true;
/* 438 */       this.mDelegate.onCommunicationAvailabilityChange(true);
/* 439 */       startCommunication(ProtocolType.FILEIO);
/* 440 */       pollEndpoints();
/*     */     }
/*     */   }
/*     */ }


/* Location:              D:\Android\FLIROneSDK-Android-1_0_2\FLIROneSDKBundle\FLIRONEExampleApplication\app\libs\flironesdk\jars\classes.jar!\com\flir\flironesdk\usb\UsbCommunicator.class
 * Java compiler version: 7 (51.0)
 * JD-Core Version:       0.7.1
 */